import * as i0 from '@angular/core';
import { Injectable, inject, Component, Input } from '@angular/core';

const PREDEFINED_COLORS = {
    blue: ['#5c8df6', '#145af2', '#447cf5', '#dbe3f4'],
    gold: ['#FFD700', '#d2b100', '#a68c00', '#796600'],
    white: ['#ffffff', '#f0f0f0', '#d8d8d8', '#b0b0b0'],
    black: ['#000000', '#333333', '#666666', '#999999'],
    red: ['#ff0000', '#cc0000', '#990000', '#660000'],
    orange: ['#ff9900', '#ff6600', '#ff3300', '#cc3300'],
    green: ['#00cc00', '#009900', '#006600', '#003300'],
    yellow: ['#ffff00', '#cccc00', '#999900', '#666600'],
    purple: ['#9933ff', '#6600cc', '#4d0099', '#330066'],
    gray: ['#D3D3D3', '#DCDCDC', '#E5E5E5', '#F0F0F0'],
    brown: ['#FFB366', '#FFC299', '#FFD1B3', '#FFE0CC'],
    cyan: ['#00FFFF', '#00CED1', '#20B2AA', '#008B8B'],
    violet: ['#8A2BE2', '#9400D3', '#800080', '#4B0082'],
    pink: ['#FFC0CB', '#FF69B4', '#FF1493', '#DB7093'],
};

class NgxCubeLoaderService {
    generateColorPalette(baseColor, paletteSize = 4) {
        const hexToRgb = (hex) => hex.match(/\w\w/g)?.map((x) => parseInt(x, 16)) ?? [];
        const rgbToHex = (r, g, b) => `#${((1 << 24) + (r << 16) + (g << 8) + b).toString(16).slice(1)}`;
        const [r, g, b] = hexToRgb(baseColor);
        const isVeryDark = r === 0 && g === 0 && b === 0;
        const brightness = isVeryDark
            ? 0
            : (0.299 * r + 0.587 * g + 0.114 * b) / 255;
        const shades = [baseColor];
        if (isVeryDark) {
            const step = 255 / (paletteSize - 1);
            for (let i = 1; i < paletteSize; i++) {
                const shade = Math.round(step * i);
                shades.push(rgbToHex(shade, shade, shade));
            }
        }
        else {
            for (let i = 1; i < paletteSize; i++) {
                const fraction = brightness < 0.5 ? 0.5 : 0.7;
                const newR = Math.round(r - (r * fraction * i) / paletteSize);
                const newG = Math.round(g - (g * fraction * i) / paletteSize);
                const newB = Math.round(b - (b * fraction * i) / paletteSize);
                shades.push(rgbToHex(newR, newG, newB));
            }
        }
        return shades;
    }
    getRandomHexColor() {
        const r = Math.floor(Math.random() * 256);
        const g = Math.floor(Math.random() * 256);
        const b = Math.floor(Math.random() * 256);
        const hex = `#${((r << 16) | (g << 8) | b)
            .toString(16)
            .padStart(6, '0')}`;
        return hex;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: NgxCubeLoaderService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: NgxCubeLoaderService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: NgxCubeLoaderService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

class NgxCubeLoaderComponent {
    constructor() {
        this.isFullSize = false;
        this.colorSet = 'blue';
        this.size = 32;
        this.duration = 800;
        this.ngxCubeLoaderService = inject(NgxCubeLoaderService);
        this.boxCount = 4;
        this.boxes = new Array(this.boxCount).fill(0);
    }
    ngOnInit() {
        const isPredefinedColorSet = typeof this.colorSet === 'string';
        if (isPredefinedColorSet) {
            if (this.colorSet === 'random') {
                const randomColor = this.ngxCubeLoaderService.getRandomHexColor();
                this.colorSet =
                    this.ngxCubeLoaderService.generateColorPalette(randomColor);
            }
            else {
                const color = this.colorSet;
                this.colorSet = PREDEFINED_COLORS[color];
            }
        }
        if (typeof this.size === 'number') {
            this.size = `${this.size}px`;
        }
        if (typeof this.duration === 'number') {
            this.duration = `${this.duration}ms`;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: NgxCubeLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.2.2", type: NgxCubeLoaderComponent, isStandalone: true, selector: "ngx-cube-loader", inputs: { isFullSize: "isFullSize", colorSet: "colorSet", size: "size", duration: "duration" }, ngImport: i0, template: `
    <div
      class="box-wrapper"
      style="--size: {{ size }}"
      aria-label="cube animation"
      [class.full-size]="isFullSize"
    >
      <div class="boxes" style="--duration: {{ duration }}">
        @for (box of boxes; track box) {
        <div class="box">
          @for (color of colorSet; track color) {
          <div style="--background: {{ color }}"></div>
          }
        </div>
        }
      </div>
    </div>
  `, isInline: true, styles: ["*{user-select:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;pointer-events:none}div.box-wrapper{--size: 32px;--gap: 15px;height:fit-content;width:fit-content;min-height:calc(var(--size) * 4 + var(--gap))}div.box-wrapper.full-size{width:100%;height:100%;display:flex;justify-content:center;align-items:center}div.box-wrapper div.boxes{--duration: .8s;height:calc(var(--size) * 2);width:calc(var(--size) * 3);position:relative;transform-style:preserve-3d;transform-origin:50% 50%;transform:rotateX(60deg) rotate(45deg) rotateY(0) translateZ(0)}div.box-wrapper div.boxes div.box{width:var(--size);height:var(--size);top:0;left:0;position:absolute;transform-style:preserve-3d}div.box-wrapper div.boxes div.box:nth-child(1){transform:translate(100%);animation:box1 var(--duration) linear infinite}div.box-wrapper div.boxes div.box:nth-child(2){transform:translateY(100%);animation:box2 var(--duration) linear infinite}div.box-wrapper div.boxes div.box:nth-child(3){transform:translate(100%,100%);animation:box3 var(--duration) linear infinite}div.box-wrapper div.boxes div.box:nth-child(4){transform:translate(200%);animation:box4 var(--duration) linear infinite}div.box-wrapper div.boxes div.box>div{--background: #5c8df6;--top: auto;--right: auto;--bottom: auto;--left: auto;--translateZ: calc(var(--size) / 2);--rotateY: 0deg;--rotateX: 0deg;position:absolute;width:100%;height:100%;background:var(--background);top:var(--top);right:var(--right);bottom:var(--bottom);left:var(--left);transform:rotateY(var(--rotateY)) rotateX(var(--rotateX)) translateZ(var(--translateZ))}div.box-wrapper div.boxes div.box>div:nth-child(1){--top: 0;--left: 0}div.box-wrapper div.boxes div.box>div:nth-child(2){--background: #145af2;--right: 0;--rotateY: 90deg}div.box-wrapper div.boxes div.box>div:nth-child(3){--background: #447cf5;--rotateX: -90deg}div.box-wrapper div.boxes div.box>div:nth-child(4){--background: #dbe3f4;--top: 0;--left: 0;--translateZ: calc(var(--size) * 3 * -1)}@keyframes box1{0%,50%{transform:translate(100%)}to{transform:translate(200%)}}@keyframes box2{0%{transform:translateY(100%)}50%{transform:translate(0)}to{transform:translate(100%)}}@keyframes box3{0%,50%{transform:translate(100%,100%)}to{transform:translateY(100%)}}@keyframes box4{0%{transform:translate(200%)}50%{transform:translate(200%,100%)}to{transform:translate(100%,100%)}}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.2.2", ngImport: i0, type: NgxCubeLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-cube-loader', standalone: true, imports: [], template: `
    <div
      class="box-wrapper"
      style="--size: {{ size }}"
      aria-label="cube animation"
      [class.full-size]="isFullSize"
    >
      <div class="boxes" style="--duration: {{ duration }}">
        @for (box of boxes; track box) {
        <div class="box">
          @for (color of colorSet; track color) {
          <div style="--background: {{ color }}"></div>
          }
        </div>
        }
      </div>
    </div>
  `, styles: ["*{user-select:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;pointer-events:none}div.box-wrapper{--size: 32px;--gap: 15px;height:fit-content;width:fit-content;min-height:calc(var(--size) * 4 + var(--gap))}div.box-wrapper.full-size{width:100%;height:100%;display:flex;justify-content:center;align-items:center}div.box-wrapper div.boxes{--duration: .8s;height:calc(var(--size) * 2);width:calc(var(--size) * 3);position:relative;transform-style:preserve-3d;transform-origin:50% 50%;transform:rotateX(60deg) rotate(45deg) rotateY(0) translateZ(0)}div.box-wrapper div.boxes div.box{width:var(--size);height:var(--size);top:0;left:0;position:absolute;transform-style:preserve-3d}div.box-wrapper div.boxes div.box:nth-child(1){transform:translate(100%);animation:box1 var(--duration) linear infinite}div.box-wrapper div.boxes div.box:nth-child(2){transform:translateY(100%);animation:box2 var(--duration) linear infinite}div.box-wrapper div.boxes div.box:nth-child(3){transform:translate(100%,100%);animation:box3 var(--duration) linear infinite}div.box-wrapper div.boxes div.box:nth-child(4){transform:translate(200%);animation:box4 var(--duration) linear infinite}div.box-wrapper div.boxes div.box>div{--background: #5c8df6;--top: auto;--right: auto;--bottom: auto;--left: auto;--translateZ: calc(var(--size) / 2);--rotateY: 0deg;--rotateX: 0deg;position:absolute;width:100%;height:100%;background:var(--background);top:var(--top);right:var(--right);bottom:var(--bottom);left:var(--left);transform:rotateY(var(--rotateY)) rotateX(var(--rotateX)) translateZ(var(--translateZ))}div.box-wrapper div.boxes div.box>div:nth-child(1){--top: 0;--left: 0}div.box-wrapper div.boxes div.box>div:nth-child(2){--background: #145af2;--right: 0;--rotateY: 90deg}div.box-wrapper div.boxes div.box>div:nth-child(3){--background: #447cf5;--rotateX: -90deg}div.box-wrapper div.boxes div.box>div:nth-child(4){--background: #dbe3f4;--top: 0;--left: 0;--translateZ: calc(var(--size) * 3 * -1)}@keyframes box1{0%,50%{transform:translate(100%)}to{transform:translate(200%)}}@keyframes box2{0%{transform:translateY(100%)}50%{transform:translate(0)}to{transform:translate(100%)}}@keyframes box3{0%,50%{transform:translate(100%,100%)}to{transform:translateY(100%)}}@keyframes box4{0%{transform:translate(200%)}50%{transform:translate(200%,100%)}to{transform:translate(100%,100%)}}\n"] }]
        }], propDecorators: { isFullSize: [{
                type: Input
            }], colorSet: [{
                type: Input
            }], size: [{
                type: Input
            }], duration: [{
                type: Input
            }] } });

/*
 * Public API Surface of ngx-cube-loader
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxCubeLoaderComponent, NgxCubeLoaderService, PREDEFINED_COLORS };
//# sourceMappingURL=ngx-cube-loader.mjs.map
